@@ -66,7 +66,12 @@ from pymongo.asynchronous.database import AsyncDatabase
 from pymongo.asynchronous.mongo_client import AsyncMongoClient
 from pymongo.common import CONNECT_TIMEOUT
 from pymongo.daemon import _spawn_daemon
-from pymongo.encryption_options import AutoEncryptionOpts, RangeOpts, TextOpts
+from pymongo.encryption_options import (
+    AutoEncryptionOpts,
+    RangeOpts,
+    TextOpts,
+    check_min_pymongocrypt,
+)
 from pymongo.errors import (
     ConfigurationError,
     EncryptedCollectionError,
@@ -675,6 +680,8 @@ class AsyncClientEncryption(Generic[_DocumentType]):
                 "python -m pip install --upgrade 'pymongo[encryption]'"
             )
 
+        check_min_pymongocrypt()
+
         if not isinstance(codec_options, CodecOptions):
             raise TypeError(
                 f"codec_options must be an instance of bson.codec_options.CodecOptions, not {type(codec_options)}"
@@ -710,7 +717,10 @@ class AsyncClientEncryption(Generic[_DocumentType]):
         self._encryption = AsyncExplicitEncrypter(
             self._io_callbacks,
             _create_mongocrypt_options(
-                kms_providers=kms_providers, schema_map=None, key_expiration_ms=key_expiration_ms
+                kms_providers=kms_providers,
+                schema_map=None,
+                key_expiration_ms=key_expiration_ms,
+                bypass_encryption=True,  # Don't load crypt_shared
             ),
         )
         # Use the same key vault collection as the callback.
