@@ -88,7 +88,7 @@ class _ClientBulk:
 
     def __init__(
         self,
-        client: MongoClient,
+        client: MongoClient[Any],
         write_concern: WriteConcern,
         ordered: bool = True,
         bypass_document_validation: Optional[bool] = None,
@@ -233,7 +233,7 @@ class _ClientBulk:
         msg: Union[bytes, dict[str, Any]],
         op_docs: list[Mapping[str, Any]],
         ns_docs: list[Mapping[str, Any]],
-        client: MongoClient,
+        client: MongoClient[Any],
     ) -> dict[str, Any]:
         """A proxy for Connection.write_command that handles event publishing."""
         cmd["ops"] = op_docs
@@ -324,7 +324,7 @@ class _ClientBulk:
         msg: bytes,
         op_docs: list[Mapping[str, Any]],
         ns_docs: list[Mapping[str, Any]],
-        client: MongoClient,
+        client: MongoClient[Any],
     ) -> Optional[Mapping[str, Any]]:
         """A proxy for Connection.unack_write that handles event publishing."""
         if _COMMAND_LOGGER.isEnabledFor(logging.DEBUG):
@@ -438,6 +438,8 @@ class _ClientBulk:
     ) -> None:
         """Internal helper for processing the server reply command cursor."""
         if result.get("cursor"):
+            if session:
+                session._leave_alive = True
             coll = Collection(
                 database=Database(self.client, "admin"),
                 name="$cmd.bulkWrite",
@@ -447,7 +449,6 @@ class _ClientBulk:
                 result["cursor"],
                 conn.address,
                 session=session,
-                explicit_session=session is not None,
                 comment=self.comment,
             )
             cmd_cursor._maybe_pin_connection(conn)
